read

Function read 

pub fn read(text: &str) -> OgeomResult<(Model, Vec<Shape>)>
Read a model and its root shapes back.

Errors

OgeomError::Construction if the text is not this format, names a version this does not know, or is malformed; OgeomError::Dangling if it names a handle that is not in the file.