pub fn parse(text: &str) -> OgeomResult<Exchange>Expand description
Parse a Part 21 exchange file.
Errors
OgeomError::Construction on malformed
syntax, with the byte offset where reading stopped making sense.
pub fn parse(text: &str) -> OgeomResult<Exchange>Parse a Part 21 exchange file.
OgeomError::Construction on malformed
syntax, with the byte offset where reading stopped making sense.