pub fn read_vrml(text: &str) -> OgeomResult<Vec<ImportedMesh>>Expand description
Read the meshes a VRML file draws.
Errors
OgeomError::Construction if the
header names no VRML version read here, or the text does not parse.
pub fn read_vrml(text: &str) -> OgeomResult<Vec<ImportedMesh>>Read the meshes a VRML file draws.
OgeomError::Construction if the
header names no VRML version read here, or the text does not parse.